@@ -1,10 +1,12 @@
 # -*- coding: utf-8 -*-
 """
-    :copyright: Copyright 2013 by Łukasz Mierzwa
+    :copyright: Copyright 2013-2014 by Łukasz Mierzwa
     :contact: l.mierzwa@gmail.com
 """
 
 
+from __future__ import unicode_literals
+
 from slumber.exceptions import SlumberHttpBaseException
 
 from upaas.cli.base import UPaaSApplication
@@ -28,7 +30,7 @@ class Show(UPaaSApplication):
 
         try:
             resp = self.api.application.get(name=name)
-        except SlumberHttpBaseException, e:
+        except SlumberHttpBaseException as e:
             self.handle_error(e)
         else:
             if not resp.get('objects'):
@@ -38,7 +40,7 @@ class Show(UPaaSApplication):
             app = resp['objects'][0]
             self.print_msg("Name: %s" % app['name'])
             self.print_msg("Created: %s" % app['date_created'])
-            self.print_msg("Packages: %d" % app['packages'])
+            self.print_msg("Packages: %d" % len(app['packages']))
             self.print_msg("Metadata:")
             for line in app['metadata'].splitlines():
                 self.print_msg("| %s" % line)
