@@ -1,10 +1,12 @@
 # -*- coding: utf-8 -*-
 """
-    :copyright: Copyright 2013 by Łukasz Mierzwa
+    :copyright: Copyright 2013-2014 by Łukasz Mierzwa
     :contact: l.mierzwa@gmail.com
 """
 
 
+from __future__ import unicode_literals
+
 from slumber.exceptions import SlumberHttpBaseException
 
 from upaas.cli.base import UPaaSApplication
@@ -28,7 +30,7 @@ class Stop(UPaaSApplication):
 
         try:
             resp = self.api.application.get(name=name)
-        except SlumberHttpBaseException, e:
+        except SlumberHttpBaseException as e:
             self.handle_error(e)
         else:
             if not resp.get('objects'):
@@ -40,7 +42,7 @@ class Stop(UPaaSApplication):
             try:
                 self.api.application(app['id']).stop.put(
                     {'name': app['name']})
-            except SlumberHttpBaseException, e:
+            except SlumberHttpBaseException as e:
                 self.handle_error(e)
             else:
                 self.log.info("Stop task queued")
